summaryrefslogtreecommitdiff
path: root/autogen.sh
diff options
context:
space:
mode:
authorAlvaro Soliverez <alvaro.soliverez@collabora.co.uk>2011-11-02 10:31:17 -0300
committerWill Thompson <will.thompson@collabora.co.uk>2011-11-21 14:49:57 +0000
commitf312040d789a823a66a3c044ceaf7da3064529fc (patch)
tree441c09bc9c189dd24201fdcbb9609188d5540815 /autogen.sh
parentb7cfa229c65ecba4d4a5e9e0ea90331e9d5bb269 (diff)
downloadtelepathy-salut-f312040d789a823a66a3c044ceaf7da3064529fc.tar.gz
Support building for Android.
This adds an autogen.sh and configure flag, --disable-submodules, to disable fetching the Wocky submodule (the flag is plural for consistency with other components), adds some missing compiler and linker flags, and adds targets for Androgenizer. Modified from a patch contributed by Derek Foreman. https://bugs.freedesktop.org/show_bug.cgi?id=42515
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh36
1 files changed, 25 insertions, 11 deletions
diff --git a/autogen.sh b/autogen.sh
index b6dff981..4da1c1ff 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -16,18 +16,32 @@ fi
autoreconf -i -f
-# Fetch Wocky if needed
-if test ! -f lib/ext/wocky/autogen.sh;
-then
- echo "+ Setting up Wocky submodule"
- git submodule init
-fi
-git submodule update
+#Check if building submodules
+build_submodules=true
+for arg in $*; do
+ case $arg in
+ --disable-submodules)
+ build_submodules=false
+ ;;
+*)
+;;
+esac
+done
+
+if test $build_submodules = true; then
+ # Fetch Wocky if needed
+ if test ! -f lib/ext/wocky/autogen.sh;
+ then
+ echo "+ Setting up Wocky submodule"
+ git submodule init
+ fi
+ git submodule update
-# launch Wocky's autogen.sh
-cd lib/ext/wocky
-sh autogen.sh --no-configure
-cd ../../..
+ # launch Wocky's autogen.sh
+ cd lib/ext/wocky
+ sh autogen.sh --no-configure
+ cd ../../..
+fi
run_configure=true
for arg in $*; do